### container

gguf-container comes with website/dApp (gguf.us) full source code plus gguf-core and its dependencies

#### install it via:
```
pip install gguf-container
```
[<img src="https://raw.githubusercontent.com/calcuis/gguf-connector/master/gguf.gif" width="128" height="128">](https://github.com/calcuis/gguf-connector)
[<img src="https://raw.githubusercontent.com/calcuis/llama-core/master/lime.gif" width="128" height="128">](https://github.com/calcuis/llama-core)
[<img src="https://raw.githubusercontent.com/calcuis/gguf-core/master/gguf.gif" width="128" height="128">](https://github.com/calcuis/gguf-core)

### user manual (gguf-core)
```
gguf -h
```
#### check current version (gguf-core)
```
gguf -v
```
#### cli connector
```
gguf c
```
#### gui connector
```
gguf g
```
#### interface selector
```
gguf i
```
#### model metadata reader
```
gguf r
```
#### get feature
```
gguf get [url]
```
#### sample model list
```
gguf s
```
#### pdf analyzor (beta)
```
gguf p
```
#### launch to container frontend via gguf:
```
gguf w
```

#### launch to the container frontend via gguf-container by:
```
python -m gguf_container
```

find container frontend (gguf.us) full source code in this pack; you can opt to run the server.py and host the frontend locally